@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ultra-scroll" "0.4.2"
+(define-package "ultra-scroll" "0.5"
   "Fast and smooth scrolling."
   '((emacs "29.1"))
   :url "https://github.com/jdtsmith/ultra-scroll"
-  :commit "077d1e32a604fc4244edbf4ff6ec0f37c738b585"
-  :revdesc "077d1e32a604"
+  :commit "21c568b1a26e597714ad65b40f246dd6e9f71fdd"
+  :revdesc "21c568b1a26e"
   :keywords '("convenience"))
